@@ -1,5 +1,5 @@
 from typing import Final, List, Optional
-from thirdweb.abi import DropERC721
+from thirdweb.abi import DropERC721_V3
 from thirdweb.common.claim_conditions import prepare_claim
 from thirdweb.constants.addresses import DEFAULT_MERKLE_ROOT
 from thirdweb.constants.role import Role
@@ -29,37 +29,38 @@ from web3 import Web3
 from thirdweb.types.tx import TxResultWithId
 
 
-class NFTDrop(ERC721[DropERC721]):
+class NFTDrop(ERC721[DropERC721_V3]):
     """
     Setup a collection of one-of-one NFTs that are minted as users claim them.
 
     ```python
     from thirdweb import ThirdwebSDK
-    from eth_account import Account
-    from web3 import Web3
 
-    # You can switch out this provider and RPC URL for your own
-    provider = Web3(Web3.HTTPProvider("<RPC_URL>"))
-    # This will create a random account to use for signing transactions
-    signer = Account.create()
+    # You can customize this to a supported network or your own RPC URL
+    network = "mumbai"
+
+    # Now we can create a new instance of the SDK
+    sdk = ThirdwebSDK(network)
+
+    # If you want to send transactions, you can instantiate the SDK with a private key instead:
+    #   sdk = ThirdwebSDK.from_private_key(PRIVATE_KEY, network)
 
-    sdk = ThirdwebSDK(provider, signer)
     contract = sdk.get_nft_drop("{{contract_address}}")
     ```
     """
 
-    _abi_type = DropERC721
+    _abi_type = DropERC721_V3
 
     contract_type: Final[ContractType] = ContractType.NFT_DROP
     contract_roles: Final[List[Role]] = [Role.ADMIN, Role.MINTER, Role.TRANSFER]
 
-    metadata: ContractMetadata[DropERC721, NFTDropContractMetadata]
+    metadata: ContractMetadata[DropERC721_V3, NFTDropContractMetadata]
     roles: ContractRoles
-    primary_sale: ContractPrimarySale[DropERC721]
-    platform_fee: ContractPlatformFee[DropERC721]
-    royalty: ContractRoyalty[DropERC721]
+    primary_sale: ContractPrimarySale[DropERC721_V3]
+    platform_fee: ContractPlatformFee[DropERC721_V3]
+    royalty: ContractRoyalty[DropERC721_V3]
     claim_conditions: DropClaimConditions
-    events: ContractEvents[DropERC721]
+    events: ContractEvents[DropERC721_V3]
 
     def __init__(
         self,
@@ -69,7 +70,7 @@ class NFTDrop(ERC721[DropERC721]):
         signer: Optional[LocalAccount] = None,
         options: SDKOptions = SDKOptions(),
     ):
-        abi = DropERC721(provider, address)
+        abi = DropERC721_V3(provider, address)
         contract_wrapper = ContractWrapper(abi, provider, signer, options)
         super().__init__(contract_wrapper, storage)
 
@@ -85,6 +86,37 @@ class NFTDrop(ERC721[DropERC721]):
         )
         self.events = ContractEvents(contract_wrapper)
 
+    def get_owned(self, address: str = "") -> List[NFTMetadataOwner]:
+        """
+        Get the metadata of all tokens owned by a specific address
+
+        ```python
+        nfts = contract.get_owned("{{wallet_address}}")
+        print(nfts)
+        ```
+
+        :param address: the address to get the metadata for
+        :return: the metadata of all tokens owned by the address
+        """
+
+        token_ids = self.get_owned_token_ids(address)
+        return [self.get(token_id) for token_id in token_ids]
+
+    def get_owned_token_ids(self, address: str = "") -> List[int]:
+        """
+        Get the token IDs owned by a specific address
+
+        :param address: the address to get the token IDs for
+        :return: the token IDs owned by the address
+        """
+
+        owner = address if address else self._contract_wrapper.get_signer_address()
+        balance = self._contract_wrapper._contract_abi.balance_of.call(owner)
+        return [
+            self._contract_wrapper._contract_abi.token_of_owner_by_index.call(owner, i)
+            for i in range(balance)
+        ]
+
     def get_all_claimed(
         self, query_params: QueryAllParams = QueryAllParams()
     ) -> List[NFTMetadataOwner]:
