@@ -10,9 +10,10 @@ from thirdweb.abi import (
     IERC20,
     IERC721,
     IERC1155,
-    DropERC721,
-    DropERC1155,
+    DropERC721_V3,
+    DropERC1155_V2,
     ThirdwebContract,
+    Multiwrap,
 )
 from thirdweb.types.settings.metadata import ContractMetadataSchema
 
@@ -29,30 +30,31 @@ TContractABI = TypeVar(
         IERC1155,
         TWRegistry,
         TWFactory,
-        DropERC721,
-        DropERC1155,
+        DropERC721_V3,
+        DropERC1155_V2,
+        Multiwrap,
         ThirdwebContract,
     ],
 )
 
-TERC721 = TypeVar("TERC721", bound=Union[TokenERC721, DropERC721])
-TERC1155 = TypeVar("TERC1155", bound=Union[TokenERC1155, DropERC1155])
+TERC721 = TypeVar("TERC721", bound=Union[TokenERC721, DropERC721_V3, Multiwrap])
+TERC1155 = TypeVar("TERC1155", bound=Union[TokenERC1155, DropERC1155_V2])
 
 TPrimarySaleABI = TypeVar(
     "TPrimarySaleABI",
-    bound=Union[TokenERC721, TokenERC1155, TokenERC20, DropERC721, DropERC1155],
+    bound=Union[TokenERC721, TokenERC1155, TokenERC20, DropERC721_V3, DropERC1155_V2],
 )
 
 TPlatformFeeABI = TypeVar(
     "TPlatformFeeABI",
     bound=Union[
-        TokenERC721, TokenERC1155, TokenERC20, Marketplace, DropERC721, DropERC1155
+        TokenERC721, TokenERC1155, TokenERC20, Marketplace, DropERC721_V3, DropERC1155_V2
     ],
 )
 
 TRoyaltyABI = TypeVar(
     "TRoyaltyABI",
-    bound=Union[TokenERC721, TokenERC1155, DropERC721, DropERC1155],
+    bound=Union[TokenERC721, TokenERC1155, DropERC721_V3, DropERC1155_V2, Multiwrap],
 )
 
 TMetadataABI = TypeVar(
@@ -62,9 +64,9 @@ TMetadataABI = TypeVar(
         TokenERC1155,
         TokenERC20,
         Marketplace,
-        DropERC721,
-        DropERC1155,
-        ThirdwebContract,
+        DropERC721_V3,
+        DropERC1155_V2,
+        Multiwrap,
     ],
 )
 
@@ -78,4 +80,5 @@ class ContractType(Enum):
     MARKETPLACE = "marketplace"
     NFT_DROP = "nft-drop"
     EDITION_DROP = "edition-drop"
+    MULTIWRAP = "multiwrap"
     CUSTOM = "custom"
